package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````[1<``#0```"4L0````0`!30`(``)
M`"@`'``;``$``'!`GP``0)\``$"?```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!,GP``3)\```4```````$`
M`0```'BM``!XK0$`>*T!`,@"``#@$@``!@```````0`"````A*T``(2M`0"$
MK0$`*`$``"@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D>*T`
M`'BM`0!XK0$`B`(``(@"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50`;_3>?Q8V-%8C8)8J#1ZJ"V$KF^!$```!1````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%$```!2````5@``
M`%L```!<````8P```&0```!E````9P```&@`````````:@```&L```!L````
M;@```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````#P$@````````,`"P``````@*T!```````#`!0`
MS0(`````````````$@```'L#`````````````!(```!/`P`````````````B
M````E`,`````````````$0```#\$`````````````!(````1````````````
M```@````/@(`````````````$@```"$#`````````````!(```!L`P``````
M```````2````)0$`````````````$@```+(#`````````````!$```#(````
M```````````2````Z`(`````````````$@```)<!`````````````!(```#4
M`@`````````````2````F```````````````$@```"`!`````````````!(`
M``#O`@`````````````2````?@(`````````````$@```$T"````````````
M`!(```"/`@`````````````2````G`(`````````````$@```!4!````````
M`````!$```![`0`````````````2````]P``````````````$0```$D!````
M`````````!(````H`P`````````````2````&@,`````````````$0```#$#
M`````````````!(```#6```````````````2````Q0$`````````````$@``
M`#8"`````````````!(```"R`0`````````````2````"`,`````````````
M$@```!X"`````````````!(```"^`0`````````````2````@@,`````````
M````$@```%<!`````````````!(````M```````````````@````L0(`````
M````````$@```%\"`````````````!(```"_`@`````````````2````T`$`
M````````````$0```'@``````````````!(````^`P`````````````2````
MIP``````````````$@```"4"`````````````!(```!>`P`````````````2
M````LP``````````````$@```&P"`````````````!(```!P`0``````````
M```2````E@(`````````````$@```,8"`````````````!(````V`0``````
M```````2````:@``````````````$@```"H!`````````````!(```"G`0``
M```````````2````V@(`````````````$@````0!`````````````!(```"J
M`@`````````````2````=`,`````````````$@```+@"`````````````!(`
M``")`0`````````````2````AP``````````````$@```)4#````````````
M`"$````\```````````````@````10,`````````````$@```.@`````````
M`````!(```!G`0`````````````2````4```````````````(````)8#````
M`````````!$````0`P`````````````2````9`(`````````````$@```*0"
M`````````````!(````8`@`````````````2````_0(`````````````$@``
M`'4"`````````````!(````$`@`````````````2````]`,``%C``0``````
M$``8`$@$``#E7@``4````!(`#0`6!```E%\````````2``X`;00``"U4``#T
M!P``$@`-`(\#```A%@``S`$``!(`#0`<!```&4\```0````2``T`Y0,``$"P
M`0``````$``8`-L$```=3P``M`$``!(`#0#5!```\!(````````2``L`"`4`
M`"%<``#$`@``$@`-`-D#``!`L`$``````!``&`!4!```T5```!8````2``T`
MAP0``)Q?```$````$0`/``<$``!8P`$``````!``&`#_`P``6,`!```````0
M`!@`TP0``/U-```X````$@`-`.@$``"-4P``H````!(`#0#Z!```'5,``&``
M```2``T`>@0```"P`0``````$``7`&$$``#I4```L````!(`#0#2`P``0+`!
M```````0`!<`O`0``#RP`0`$````$0`7``P$``"17P```@```!(`#0"L!```
M55\``#P````2``T`@`0``.T7````````$@`-`'P$````L`$``````"``%P`M
M!```?5,``!`````2``T`\P,``%C``0``````$``8`)8$``"!3@``F````!(`
M#0#&!```F5$``(0!```2``T``&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A
M<`!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A
M9%]G971S<&5C:69I8P!C;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L
M<V5E:S8T`')E860`;&EB8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`
M<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N
M;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K
M`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M
M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V
M-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`
M<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L
M9"UL:6YU>"UA<FUH9BYS;RXS`%]?<W1A8VM?8VAK7V=U87)D`&QI8F-R>7!T
M+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`7U]B<W-?
M96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N
M=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A
M7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?
M7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET
M`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0``````````@`"``(`
M`@`"`````P`"``(``@`$`````@````(```````(``@`"``(``@``````````
M``(``@`"```````#`````@`#``(``@```````@`"``(```````(````#``(`
M```"`````@`"`````````````@````(``@`"```````"`````@`````````"
M``(``@`"``,``@`"``,``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`G@,``!`````@
M````%&EI#0``!``>!0````````$``0#T`0``$````"`````4:6D-```#`!X%
M`````````0`!`$,"```0`````````!1I:0T```(`'@4```````!XK0$`%P``
M`'RM`0`7````N*\!`!<```#<KP$`%P```.2O`0`7````[*\!`!<````$L`$`
M%P````RP`0`7````$+`!`!<````8L`$`%P```!RP`0`7````(+`!`!<````D
ML`$`%P```"BP`0`7````,+`!`!<````TL`$`%P```#RP`0`7````O*\!`!4%
M``#`KP$`%0@``,2O`0`5#0``R*\!`!40``#,KP$`%1D``-"O`0`5&P``U*\!
M`!4>``#8KP$`%2D``."O`0`5+0``Z*\!`!4X``#PKP$`%4(``/2O`0`51```
M^*\!`!5(``#\KP$`%4D``+BN`0`6`P``O*X!`!8$``#`K@$`%@4``,2N`0`6
M!P``R*X!`!8)``#,K@$`%@H``-"N`0`6"P``U*X!`!8,``#8K@$`%@X``-RN
M`0`6#P``X*X!`!81``#DK@$`%A(``.BN`0`6$P``[*X!`!84``#PK@$`%A4`
M`/2N`0`6%@``^*X!`!87``#\K@$`%A@```"O`0`6&@``!*\!`!8<```(KP$`
M%AT```RO`0`6'P``$*\!`!8@```4KP$`%B$``!BO`0`6(@``'*\!`!8C```@
MKP$`%B0``"2O`0`6)0``**\!`!8F```LKP$`%B<``#"O`0`6*```-*\!`!8I
M```XKP$`%BH``#RO`0`6*P``0*\!`!8L``!$KP$`%BX``$BO`0`6+P``3*\!
M`!8P``!0KP$`%C$``%2O`0`6,@``6*\!`!8S``!<KP$`%C0``&"O`0`6-0``
M9*\!`!8V``!HKP$`%C<``&RO`0`6.0``<*\!`!8Z``!TKP$`%CL``'BO`0`6
M/```?*\!`!8]``"`KP$`%CX``(2O`0`6/P``B*\!`!9```",KP$`%D$``)"O
M`0`610``E*\!`!9&``"8KP$`%D<``)RO`0`62@``H*\!`!9+``"DKP$`%DP`
M`*BO`0`630``K*\!`!9.``"PKP$`%D\``+2O`0`64```"$`MZ4X!`.L(@+WH
M!.`MY03@G^4.X(_@"/"^Y:";`0``QH_B&<J,XJ#[O.4`QH_B&<J,XIC[O.4`
MQH_B&<J,XI#[O.4`QH_B&<J,XHC[O.4`QH_B&<J,XH#[O.4`QH_B&<J,XGC[
MO.4`QH_B&<J,XG#[O.4`QH_B&<J,XFC[O.4`QH_B&<J,XF#[O.4`QH_B&<J,
MXEC[O.4`QH_B&<J,XE#[O.4`QH_B&<J,XDC[O.4`QH_B&<J,XD#[O.4`QH_B
M&<J,XCC[O.4`QH_B&<J,XC#[O.5X1\!&`,:/XAG*C.(D^[SE`,:/XAG*C.(<
M^[SE`,:/XAG*C.(4^[SE`,:/XAG*C.(,^[SE`,:/XAG*C.($^[SE`,:/XAG*
MC.+\^KSE`,:/XAG*C.+T^KSE`,:/XAG*C.+L^KSE`,:/XAG*C.+D^KSE`,:/
MXAG*C.+<^KSE`,:/XAG*C.+4^KSE`,:/XAG*C.+,^KSE`,:/XAG*C.+$^KSE
M`,:/XAG*C.*\^KSE`,:/XAG*C.*T^KSE`,:/XAG*C.*L^KSE`,:/XAG*C.*D
M^KSE`,:/XAG*C.*<^KSE`,:/XAG*C.*4^KSE`,:/XAG*C.*,^KSE`,:/XAG*
MC.*$^KSE`,:/XAG*C.)\^KSE`,:/XAG*C.)T^KSE`,:/XAG*C.)L^KSE`,:/
MXAG*C.)D^KSE`,:/XAG*C.)<^KSE>$?`1@#&C^(9RHSB4/J\Y7A'P$8`QH_B
M&<J,XD3ZO.4`QH_B&<J,XCSZO.4`QH_B&<J,XC3ZO.4`QH_B&<J,XBSZO.4`
MQH_B&<J,XB3ZO.4`QH_B&<J,XASZO.4`QH_B&<J,XA3ZO.4`QH_B&<J,X@SZ
MO.4`QH_B&<J,X@3ZO.4`QH_B&<J,XOSYO.4`QH_B&<J,XO3YO.4`QH_B&<J,
MXNSYO.4`QH_B&<J,XN3YO.4`QH_B&<J,XMSYO.4`QH_B&<J,XM3YO.4`QH_B
M&<J,XLSYO.4`QH_B&<J,XL3YO.4`QH_B&<J,XKSYO.4`QH_B&<J,XK3YO.4`
MQH_B&<J,XJSYO.4`QH_B&<J,XJ3YO.4`QH_B&<J,XISYO.4`````\+6)L%Y,
M7TM\1`60!)$%J`.2!*GF6`.J,V@'D__W/.]92EI+HEC@6!%&!/!S_%A+XU@?
M>``O<=!62^58*&C_]]COD/@.-`)&*&A#\`(#@O@.-/_WSN\%FP4SL_&`3Y#X
M#B1"\`$"@/@.)'32F`#_]]CN24L$G4_P!`Y[1$=*2$DO:'I$'&AY1$9+>T1#
M^/3L0F`%FL%@`2I#^/`,!V#(ORL=A&#$OP7K@@4`\0P!!=U3^`1+G4)!^`1/
M^=$Z3P+Q@$$`)`,Q?T0`E$#X(4`#1E?XZ%P#,C5)*$9Y1/_W*.\$1F"S,DT&
MKWU$5?CH#/_W;NXP2#E&>$0#\$KY*+,N2WM$4_CH#/_W/.[_]P;O!YHS:"!&
MFD(NT0FP\+W_]W3N)DIZ1$+XZ`PXL__W).X92^58*&C_]USO@/B!=G[G5_CH
M#/_W+.\$1LSG5?CL#$"Q!/"X^]/G&DL:2.%8>$3_][KN&4@Y1GA$`_`2^47X
M[`P`*,30[.?_]Q#N`2#_]X#N@)@!`!@!```\`0``1`$``"0!```@`0``GID!
M`#9,```V3```CJH!`%*J`0`W-P``,*H!`'I)```8J@$`]JD!`#0!```X2@``
MID@``$_P``M/\``.`KQJ1@2T`;3?^"2@"*.:1-_X(,!:^`S`3?@$S09+6O@#
M,`9(6O@``/_W*.[_]][NB)8!``P!```X`0``0`$``!0PG^44()_E`S"/X`(@
MD^<``%+C'O\O`0W__^IHE@$`+`$```=+"$A[1`A*>$0#,QL:>D0&*P/9!4O3
M6`.Q&$=P1P"_X)<!`-R7`0!"E@$`%`$```A)"4AY1`E+>$0)&GM$B1`!Z]%Q
M21`#T`5*FU@#L1A'<$<`O["7`0"LEP$`%)8!`$P!```(M0I+"DI[1'I$&WAK
MN0E+TU@CL0A+>T08:/_W*.W_][W_!DL!(GM$&G`(O7J7`0#DE0$`$`$``"Z7
M`0!:EP$`!T@(M7A$`F@&2WM$$KF]Z`A`N^<$2IM8`"OXT)A']N=\E`$`HI4!
M`$@!``#?^.0NW_CD/BWI\$]Z1*WU/WT`\3@%'*P`\7@.`)0`)AJ0TUC-Z0:)
M&Y,;:+V3:&@(-0.6$#0%E@,*`I,##@23W>D"(P$&W>D$B0`C`O1_0E7X"'Q(
MZ@((3^H`*DGJ`PEU14)&"O1_`$+J`0)$^`QL2T8_ND_P``%"Z@`"0^H!`T3X
M$'Q$Z0(CT=$-\6@.#?4:?'1&_ND"`=3I'&?4Z1(CU.D&17)`>T!B0&M`0D!+
M0)`8YD5/ZM)X2.I#"$_P``-`Z@@"SND@(^/1&I@`)0"9+T;0Z0`TT>D`B:-&
M`"0F1LWI!F=>1II&=0$&1M#I`@%%ZMIES>D(JP_VW%S<Z0"\*D;-Z1`!,$;6
MZ01G&^L("TSK"0S81LWI!&<&1M#I!@'A1M;I"&?=Z02\S>D*`5!&S>D49T0!
MW>D*9R)#W>D418OJ!@N,Z@<,%.L(!%Y&W>D0JT7K"06@1F=&&.L""%1&!.H&
M!*E&748F1@7J!P7=Z0HT2?$`"2]&749S0*T'!Y5\0!Y&!YL8ZP8"548G1D/J
MF@,'DTGK!P-41J@(0.J+<)M&HP<`G`:3%T9/\``(3_``"<WI`GBF1I)&U.D"
M1=WI!B-+1MWI`HE/\``,S>D&10)#S>D,(T1&W>D$B>8.W>D"18CJ`@B)Z@,)
M#_;L0]/I`"-&ZD46W>D&1:0874$B1BM&W>D(103J"`0%Z@D%H$8"G*E&8`'=
MZ0I%,$.D&%U!S>D&1=WI!#3=Z09G@^H(`X3J"03=Z0B)]AAG0<WI!F='1KP(
MW>D&9T3JB70V&$!&3^J`<D?Q``<B0][I!$4*Z@(*S>D.9Q-&W>D.B<WI%D4`
M)2Q&"^H%"\WI$C1/\``)W>D6-$_J21?-Z0:K1^K89P_V1$O;Z0"K3^I(%D_J
MV6$`(!KK`PK=Z0PC2^L$"]WI!$44ZPH$1>L+!=WI`JLBZ@H*(^H+"U)&6T9'
MZ@8*0>H'"]WI!F?-Z1:KW>D"JQ9#I!E'Z@,'?4%11B9&C`@6F1;K`0K=Z0)G
M1?$`"\WI%JM/\``+S>D"JT3JAW2R!R)#W>D"1=[I!F<`(9-&S>D&`6L!!Y,/
M]K`ST^D`(^`.0.I%$)(9>T$61A]&W>D.(\WI#KP"Z@L"`^H,`Y)&!YJ;1D+J
MU&,'D]WI#"-D`0:4DAG=Z09%>T$61@1#'T;=Z1(C`"`BZ@@"(^H)`TKJ`@I+
MZ@,+%NL*!D_JB7-'ZPL'%NL$"T?Q``Q#ZI@#3^J(<EY&9T9/\``,V$8:0\WI
M&&=C1M[I"&=/\``)#_8</-SI`+Q/ZDD5S>D,(T7JV&4;ZP8+3^I(%$SK!PQ/
MZMEA7D;=Z1:K"NH""@OJ`PO=Z1(CDAG=Z0)G0^L,`\WI!B/=Z0XC3_``#"+J
M!@8CZ@<'2NH&"DOJ!PO=Z09G%NL*!D7J!`I'ZPL'0>H%"\WI!JO=Z0*K44:,
M"`:9%NL!"D_P``%'\0`+W>D"9\WI%JM/\``+S>D"JT3JAW2R!R)#W>D"1<WI
M!@'>Z0IGDT9K`0>3#_9H(]/I`"/@#LWI$KQ`ZD40DAE[019&'T;=Z1@C`NH+
M`@/J#`.21@>:FT9"ZM1C!Y/=Z0XC9`$&E-Q&DAE[019&'T;=Z0PCW>D&12+J
M"`(CZ@D#2NH""TSJ`PP6ZPL&1.H`!$?K#`=/ZHES%NL$"T/JF`-'\0`,3^J(
M<LWI&+Q/\``,V$;>Z0QG&D-C1@_VW!S<Z0"\3_``"<WI#B-/ZDD5&^L&"T7J
MV&5,ZP<,3^I(%%Y&W>D6JT_JV6$`(`KJ`@H+Z@,+W>D,(Y(9W>D"9T/K#`/-
MZ08CW>D2(T_P``PBZ@8&(^H'!TKJ!@I+Z@<+W>D&9Q;K"@9%Z@0*1^L+!T'J
M!0O-Z0:KW>D"JU%&C`@&F1;K`0I/\``!1_$`"]WI`F?-Z1:K3_``"\WI`JM$
MZH=TL@<B0]WI`D7-Z08!WND.9Y-&:P$'DP_V(!/3Z0`CX`[-Z0R\0.I%$)(9
M>T$61A]&W>D8(P+J"P(#Z@P#DD8'FIM&0NK48P>3W>D2(V0!!I3<1I(9W>D&
M17M!%D8$0Q]&W>D.(P`@(NH(`B/J"0-*Z@(+3.H##!;K"P9/ZHES1^L,!Q;K
M!`M'\0`,0^J8`T_JB')>1F=&3_``#-A&&D/-Z1AG8T;>Z1!G3_``"0_VC`S<
MZ0"\3^I)%<WI$B-%ZMAE&^L&"T_J2!1,ZP<,3^K985Y&W>D6JPKJ`@H+Z@,+
MW>D.(Y(9W>D"9T/K#`/-Z08CW>D,(T_P``PBZ@8&(^H'!TKJ!@I+Z@<+W>D&
M9Q;K"@9%Z@0*1^L+!T'J!0O-Z0:KW>D"JU%&C`@&F1;K`0I/\``!1_$`"]WI
M`F?-Z1:K3_``"\WI`JM$ZH=TL@<B0]WI`D7-Z08!WND29Y-&:P$'DP_RV'/3
MZ0`CX`[-Z0Z\0.I%$)(9>T$61A]&W>D8(P+J"P(#Z@P#DD8'FIM&0NK48P>3
MW>D,(V0!!I3<1I(9W>D&17M!%D8$0Q]&W>D2(P`@(NH(`B/J"0-*Z@(+3.H#
M#!;K"P9/ZHES1^L,!Q;K!`M'\0`,0^J8`\WI&+Q/ZHAR3_``#-A&WND49QI#
M8T8/\DA\W.D`O,WI#"-/\``)&^L&"T_J215,ZP<,1>K895Y&W>D6JT_J2!1/
MZMEA"NH""@OJ`PO=Z1(CDAG=Z0)G0^L,`\WI!B/=Z0XC3_``#"+J!@8CZ@<'
M2NH&"DOJ!PO=Z09G%NL*!D7J!`I'ZPL'0>H%"\WI!JO=Z0*K44:,"`:9%NL!
M"D_P``%'\0`+W>D"9\WI%JM/\``+S>D"JT3JAW2R!R)#W>D"1<WI!@'>Z19G
MDT9K`0>3#_*08]/I`"/@#LWI$KQ`ZD40DAE[019&'T;=Z1@C`NH+`@/J#`.2
M1@>:FT9"ZM1C!Y/=Z0XC9`$&E-Q&DAG=Z09%>T$61@1#'T;=Z0PC`"`BZ@@"
M(^H)`TKJ`@M,Z@,,%NL+!D_JB7-'ZPP'%NL$"T?Q``Q#ZI@#S>D8O$_JB')/
M\``,V$;>Z1AG&D-C1@_R!&S<Z0"\S>D.(T_P``D;ZP8+3^I)%4SK!PQ%ZMAE
M7D;=Z1:K3^I(%$_JV6$*Z@(*"^H#"]WI#".2&=WI`F=#ZPP#S>D&(]WI$B-/
M\``,(NH&!B/J!P=*Z@8*2^H'"]WI!F<6ZPH&1>H$"D?K"P=!Z@4+S>D&J]WI
M`JM11HP(!ID6ZP$*3_```4?Q``O=Z0)GS>D,JT_P``O-Z0*K1.J'=+('(D/>
MZ1IGW>D"1<WI!@&31LWI%KQK`0>3#_)(4]/I`"/@#D#J11"2&7M!%D8?1MWI
M&","Z@L"`^H,`Y)&!YJ;1D+JU&,'D]WI$B-D`0:4W$:2&=WI!D5[019&!$,?
M1MWI#B,BZ@@"(^H)`TKJ`@M,Z@,,%NL+!D_JB7-'ZPP'%NL$"T?Q``Q#ZI@#
M3^J(<EY&9T9/\``,V$8:0\WI!F=C1M[I'&=/\``)#_*X3-SI`+Q/ZDD5S>D2
M(T7JV&4;ZP8+3^I(%$SK!PQ/ZMEA7D;=Z0RK"NH""@OJ`PO=Z0XCDAG=Z0)G
M0^L,`\WI#"/=Z18C(NH&!B/J!P=*Z@8*2^H'"]WI#&<`(Q;K"@9%Z@0*1^L+
M!T'J!0O-Z0RKW>D"JU%&C`@,F1;K`0I/\``!1_$`"]WI`F?-Z0ZK3_``"T_J
M2Q5$ZH=TL@<B0][I'F=%ZMIE3^I*%!!&`"+-Z0(C3^K:8P*3_Z/3Z0`CS>D,
M`9(9>T'=Z0QG$$891MWI!B,"E3)`.T`61A]&W>D6(X`864'=Z1(C(NH(`B/J
M"0,60Q]#,D9/ZMMF`Y:&&#M&0>L#!]WI`@$`(QU&`"(@0T_JB7,41D/JF`/-
MZ0)%3^J(<D_JF`1/ZID!`I1/\``(-!A/\``)`I-'\0`%2T;>Z2!GS>D6145&
M#_)L.=GI`(D#D=WI`@$8ZP8(2>L'"<WI`D400T9&3T;=Z0Z)`D8`(0`@S>D&
M`6D!X`X'D0CJ`@C=Z0)%">H#"<WI#B,'FD#J11!"ZM1C!Y/=Z1(C9`$&E)(9
MW>D&17M!%D8$0Q]&W>D,(P`@(NH*`B/J"P-(Z@((2>H#"1;K"`9/ZHMS1^L)
M!Q;K!`A'\0`)0^J:`\WI&(E/ZHIR3_``"<)&WNDB9QI#2T8/\L0IV>D`B<WI
M$B-/\``+&.L&"$_J2Q5)ZP<)1>K:949&3^I*%$]&W>D6B4_JVV$(Z@((">H#
M"=WI#".2&7M!W>D"9\WI!B/=Z0XC(NH&!B/J!P=(Z@8(2>H'"=WI!F<6ZP@&
M1>H$"$?K"0=!Z@4)S>D&B=WI`HE!1HP(!ID6ZP$(3_```4?Q``G=Z0)GS>D6
MB<WI`@$`(43JAW2R!T=&3_``",WI!G@B0]WI!D6)1M[I)&>01LWI#(D-];A^
M:P$#DX"CT^D`(^`.J49`ZD40DAE[019&'T;=Z1@C`NH(`@M`S>D&(Z!&`YI/
MZIL!0NK48P.3W>D.(V0!`I22&=WI!D5[0<WI!HD61MWI`HD?1MWI$B-(Z@`(
M(NH*`B/J"P,40QU#-AE/ZHIT;T$6ZP@"1_$``T_JBW5%ZIH%%T:81@";1.H%
M"T7J`0S-Z0YX`"201@`E($8I1LWI`@%/ZMAA`I%>1MWI%@%G1M/I)B-/\``*
M#_)0'-SI`+PP0,WI&&<`)SE`S>D69]WI$F<;ZP(+3.L##-WI!B,6ZPL&3^I*
M%4?K#`?=Z0R\T49%ZMAE+.H#`P*5"T,KZ@("3^K:80.1W>D"JT_J2!0"0P`@
MMAA*Z@0*7T$6ZPH"W>D&JT?Q``,61A]&`"-:1LWI$F>5!U)&E`=:1D7JF@61
M"`":1>H!"T3J!0K=Z1A%'T;-Z0:KTNDH(X7J"P4/\K0,W.D`O(3J"@0`(<WI
M`@$;ZP(+($9,ZP,,>0%<1MWI#JL#D2E&BNH`"F5&B^H!"\WI#JO=Z0R\<0$#
MF_(.`I$;ZP0+#IE,ZP4,0^K68T_JB74#DQOK`0I%ZI@%W>D"`4_JB'1/ZID!
M1.H%"$+J1Q)%Z@$)0.H"`$SQ``L:ZP`*249`1MWI!HE+\0`+`)L`)(CJ``C-
MZ1BK3_``"P`ET^DJ(\WI`D4.X`"_K_,`@)EY@EH`````H>O9;@````!TE0$`
M&`$``$_J2Q0#E$1&#_:4:=GI`(F]!\WI#`%%ZI8%&.L""$_JVF))ZP,)`YM`
M1D+J2Q))1MWI$HE#ZMIC`Y.(Z@0(1$;=Z1:)&.L`"$GK`0D8ZP0`3^I*$0*1
M2?$``8!&M`<`GHE&W>D"`;D($$-%Z@$'&.L`"$GQ``G-Z1*)UNDL(T3J!08Y
M1MWI#$4P1LWI#@$/]A!AT>D``71`3_``"4_J2!:`&$_J21=90=WI&"/-Z18!
M1^K89P:98D`"ET_JV6,41@.3"D;=Z18!3^J+=8`81>J:!4'Q``$"&4'Q``/-
MZ08CW>D"(T_JBG1/ZIL!1.H%"C)#W>D&9T7J`0M41K881_$`!UU&,D;=Z0ZK
M.T;-Z18C`)H`(Q]&#_:(7-SI`+QY`8KJ!`K2Z2XCS>D&151&&^L""T_JB75,
MZP,,0>K68]WI$A)%ZI@%`Y/R#F%`0NI'$@";#$8,F1OK`0!,\0`!`!E/ZHAT
MBT9/ZD81`I%+\0`!@D9$Z@4(BT;=Z0(!3^J9`0`D1>H!"1!#&NL`"D!&24;=
MZ0:)2_$`"\WI$JN(Z@`(3_``"]/I,",`)<WI`D5/ZDL4`Y1$1@_VZ$G9Z0")
MO0?-Z0P!1>J6!1CK`@C=Z1822>L#"0.;84!/ZMIB0^K:8P.3#$8.F4+J2Q(8
MZP$`2?$``0`93^J&=`">B49/ZDH1`I%)\0`!@$:)1MWI`@&Y"!!#1>H!!];I
M,B-$Z@4&&.L`"#E&,$;-Z0X!#_9T0='I``%)\0`)W>D,14_JBW6`&,WI%HE9
M0=WI$B-T0,WI&`$&F6)`3_``"4_J2!841D_J21<*1MWI&`%'ZMAG3^K98X`8
M`Y,"ET'Q``$"&47JF@5!\0`#S>D&(]WI`B-/ZHIT3^J;`43J!0HR0]WI!F=%
MZ@$+5$:V&$?Q``==1C)&W>D.JSM&S>D2(P":`",?1@_VX#S<Z0"\>0&*Z@0*
MTNDT(\WI!D541AOK`@M/ZHEU3.L##$'JUF/=Z182\@X#DT+J1Q)A0$7JF`4`
MFPQ&#)D;ZP$`3/$``0`93^J(=(M&3^I&$0*12_$``8)&1.H%"(M&W>D"`4_J
MF0$`)!!#1>H!"1KK``K3Z38C2_$`"\WI%JM/\``+0$9)1@`ES>D"14_J2Q0#
ME+T'W>D&B47JE@7-Z0P!B.H`"$1&#_8T.=GI`(D8ZP((W>D2$DGK`PD#FV%`
M3^K:8D/JVF,#DPQ&#IE"ZDL2&.L!`$GQ``$`&4_JAG0`GHE&3^I*$0*12?$`
M`8!&B4;=Z0(!N0@00T7J`0?6Z3@C1.H%!ACK``@Y1C!&S>D.`0_VS"'1Z0`!
M2?$`"=WI#$5/ZHMU@!C-Z1*)64'=Z18C=$#-Z1@!!IEB0$_P``E/ZD@6%$9/
MZDD7"D;=Z1@!1^K89T_JV6.`&`*7`Y-!\0`!`AE%ZIH%0?$``\WI!B/=Z0(C
M3^J*=$_JFP%$Z@4*,D/=Z09G1>H!"U1&MAA'\0`'748R1MWI#JL[1LWI%B,`
MF@`C'T8/]C@LW.D`O'D!BNH$"M+I.B/-Z09%5$8;ZP(+3^J)=4SK`PQ!ZM9C
MW>D2$O(.`Y-"ZD<284!%ZI@%#$8,F1OK`0!,\0`!`!E/ZHAT3_``#(M&3^I&
M$0*12_$``8)&1.H%"(M&W>D"`4_JF0$00T7J`0D:ZP`*0$9+\0`+S>D2JP";
M24;=Z09%3_``"\WI#`%/ZDL9T^D\(T1`#_:<$='I``%)ZMIIS?@(D$_J2AB`
M&$_JAW590=WI%B/-Z1@!3^K;8PZ98D`#DT7JE@441@I&W>D8`8`80?$``0(9
M0?$``\WI#B/=Z0(CM`>Y"``C0NH(`MWI#HD`GACK`@A)\0`)S>D6B4)&S>D"
M(T3J!0)%Z@$#UND^9T_JFP4<1A-&`YK-Z0XT3^I"&=WI#!)90`_V"!/3Z0`C
MDAE[01]&`IM)ZM-IW>D2-$M`&$8&F]88`IM'\0`',AA/ZHIV3^I#&$?Q``-(
MZ@D`3^J+=Q(81^J:!T/Q``/>Z0")$48-]1Y^&D9'Z@4#S>D2$@`B"$811D;J
M!P(?1MWI#C1/ZD$;%D;-Z09G4T!+ZM!K3^I`&AQ&#_:(`]/I`",2ZP@"0^L)
M`]WI%HD?1@R;B.H$"$OJ"@36&-WI`JM'\0`'%NL(`D?Q``,2&4/Q``-/ZHMY
MS>D6(P`D$T;-Z0`T6T9)ZIH)3^J*>)\(2.H)!$GJ!P5>J]WI!G@N1B5&`9QO
M0-/I`",/]AP)V>D`B4_J1!L`G!CK`@C-Z0)62>L#"4OJU&L.G$)&2T82&=WI
M$HD`G$/Q``.(Z@<(3^J!>4GJD`F/"$_J1!I&1I092NH+`D/Q``5/ZH!X%.L"
M"DCJ"01%\0`+2>H'!=WI`HDF1B]&8*F(Z@0(W>D61='I``$`(X3J"`3-Z0QG
M#_*8=]?I`&=21J!&!IS-Z0ZK-AA/ZD,;3T%+ZMIK-AE/ZDH:1_$`!TOJ"@`6
MZP@$1_$`!13K``I%\0`+W>D`15!&S>D2JT_P``I/\``+3^J%>4_JA'A)ZI0)
MKPC-Z0"K8JQ(Z@D*2>H'"]WI#'AA1M3I`$5.`<WI!JN'Z@H'#_(<>MKI`)H!
MEAGK!`D!G$KK!0K+1D3JT&3=Z0Z)3^J#>0&42>J2"0*<B.H'")\(9*L;ZP0$
M1D9*\0`%3^K0:*)&1`$`E!KK!@1%\0`%2.I!&*)&JT;=Z0!%2>H'!43J"`1/
MZH)X&NL$"DCJ"03=Z0:)2_$`"\WI%JM/\``+S>D`JR9&T^D`(R]&`9R(Z@8(
MS>D"9T_J@7D/\H1FUND`5DGJD`E/ZD0;K1A>00";-T9+ZM-KW>D2-`R<@^H(
M`T_J@'@N&0"<1_$`!T_J1!KT&$KJ"P9'\0`%BP@4ZP8+1?$`#$CJ"01)Z@,%
M9JF@1MWI`B/1Z0`!J4;-Z0Z)`"</\AQIV>D`B6)`!IQ>1ACK``C-Z0R\2>L!
M"4_J1QM`1DOJUFM)1MWI%HD`&4_J1AJ(Z@((0?$``4_P``Q"1H082NH+`$'Q
M``44ZP`*849%\0`+W>D`15!&S>D2JT_JA7E/ZH1X2>J4"6BLJPA(Z@D*U.D`
M14GJ`PM21MWI#II;1@_RG%O;Z0"KS>D610`DS>D&(P`ES>D`14P!`92)Z@()
MW>D6-,(.0NI,$D_JAG@3ZPH#1.L+!)I&`9NC1D/JT&,!D]WI##0"G(/J"0-/
MZH=Y&NL$!$GJE@E+\0`%:JZB1D0!`)0:ZP,$1?$`!0`CHD:K1MWI`$6]"!1#
M&NL$"DOQ``O-Z1:K4D;-Z0`C2>H%`TCJ"0+=Z0:)UND`JXCJ`@B)Z@,)S>D,
M(P`B1$9-1@_R\$G9Z0")`"/-Z0(C&.L*"$GK"PG"1LM&W>D`B4-&VPX"DP*;
M0^I)$]WI$HD"DXCJ!`@.G(GJ!0G-Z1*)&NL$`T_JD05+\0`$W>D`JYA&;*E3
M1D_J@'I>`5M&VPX#DQ*;3^J,>TOJD`L8ZP,(1/$`"4)&2T;=Z0*)2.H&"!+K
M"`9*Z@L"0_$`!TOJ!0.P1M'I`$6Y1MWI#&?-Z0XC3^I(&A9#S>D2B4_P``DP
M1MWI%F=/ZDD;!D!+ZMAK,$;=Z0QG%D`/\C1#T^D`(S!#2^H*!A(9W>D`JVM!
M'48&F](81?$``Q(80_$``\WI`B-;1IT'4T;=Z0*KF`ANJQKK!@K=Z0!G2_$`
M"\WI%JM/\``+S>D`JT7JE@5`ZH=PM`>Y"$3J``I%Z@$+W>D.1<WI!JO=Z1*\
M1.H*`M/I``$+Z@(+#)L!GEI&W>D&JP_RK#S<Z0"\`)\$Z@H$&^L`"T_J1A9,
MZP$,&^L#"P";1NK79@.60NH$!DSQ``P;ZP8+3^K39$_J0Q,"DTSQ``P!FT_J
MB7'=Z0)G0>J8`4_JB'!$ZD,43^J9`R9#W>D&11OK!@M/\``)3/$`#,WI$KS8
M1D#J`0M!Z@,,1.H+`LWI#+QPJ]WI%JM/ZDD6W>D,O$;JV&8*Z@(*T^D``03J
M"P0.FU)&#_((.]OI`*L#ED+J!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*32_$`
M"QKK!@K=Z0)G1.I)%$OQ``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(
MW>D,14'JE@&P!T'J`PM61D#J`0K-Z0ZKW>D2O$3J"@)RJ\WI`&<+Z@(+`9[3
MZ0`!6D;=Z0ZK#_*`+-SI`+QV`0:;!.H*!!OK``L`GTSK`0P;ZP,+`)M,\0`,
M1NK79@.60NH$!D_JB7'<#EL!`I,;ZP8+`9M!ZI@!W>D"9TSQ``Q/ZHAP1.I#
M%$_JF0,F0T_P``D;ZP8+3^I)%DSQ``S-Z1*\0>H##'2KV$9`Z@$+T^D``4;J
MV&;=Z0Y%S>D&O$3J"P+=Z1:KW>D&O`KJ`@H,FP3J"P0#EE)&#_+<&]OI`*M"
MZ@0&3^K89!KK``I$ZDD42^L!"QKK`PI/ZD@3`I-+\0`+&NL&"MWI`F=+\0`+
M`"<F0S1&`9X:ZP0*`9Q+\0`+S>D6J[$'`)ZC"-WI!D5!ZI8!L`=!Z@,+5D9`
MZ@$*S>D,J]WI$KQ$Z@H"=JO-Z0!G"^H""P&>T^D``5I&W>D,JP_R5!S<Z0"\
M=@$.FP3J"@0;ZP`+`)],ZP$,&^L#"P";3/$`#$;JUV8#ED+J!`9/ZHEQW`Y;
M`0*3&^L&"P&;3/$`#-WI`F=!ZI@!3^J(<$3J0Q1/ZID#)D/=Z0Q%&^L&"T_P
M``E,\0`,S>D2O-A&0.H!"T'J`PQ$Z@L"S>D.O'BKW>D6JT_J21;=Z0Z\1NK8
M9@KJ`@K3Z0`!!.H+!`.64D8/\K0+V^D`JP:;0NH$!AKK``I/ZMAD2^L!"QKK
M`PI/ZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<2_$`
M"\WI%JNQ!P">HPC=Z0Y%0>J6`;`'0>H#"U9&0.H!"LWI!JO=Z1*\1.H*`GJK
MS>D`9POJ`@L!GM/I``%:1MWI!JL/\BP,W.D`O'8!#)L$Z@H$&^L`"P"?3.L!
M#!OK`PL`FPG@K_,`@*'KV6X`````W+P;CP````!,\0`,1NK79@.60NH$!D_J
MB7'<#EL!`I,;ZP8+`9M,\0`,W>D"9T'JF`%/ZHAP1.I#%$_JF0,F0]WI!D4;
MZP8+3_``"4SQ``S-Z1*\V$9`Z@$+0>H##$3J"P+-Z0R\?*O=Z1:K3^I)%MWI
M#+Q&ZMAF"NH""M/I``$$Z@L$#IM21@_VE&O;Z0"K`Y9"Z@0&&NL`"D_JV&1+
MZP$+&NL#"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+\0`+`"<F0S1&`9X:ZP0*
M2_$`"[$'`)X!G,WI%JM!ZI8!L`>C"-WI#$5!Z@,+5D9`Z@$*S>D.J]WI$KQ$
MZ@H"?JO-Z0!G"^H""P&>T^D``5I&W>D.JP_V#&S<Z0"\=@$&FP3J"@0;ZP`+
M`)],ZP$,&^L#"P";3/$`#$;JUV8#ED+J!`9/ZHEQW`Y;`0*3&^L&"P&;3/$`
M#-WI`F=!ZI@!3^J(<$3J0Q1/ZID#)D/=Z0Y%&^L&"T_P``E,\0`,S>D2O-A&
M0.H!"T'J`PQ$Z@L"S>D&O("KW>D6JT_J21;=Z0:\1NK89@KJ`@K3Z0`!!.H+
M!`R;4D8/]FQ;V^D`JP.60NH$!AKK``I/ZMAD2^L!"QKK`PI/ZD@3`I-+\0`+
M&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<2_$`"\WI%JNQ!P">HPA!
MZI8!L`=!Z@,+@JM61D#J`0K-Z0!GT^D``=WI!D7-Z0RKW>D2O$3J"@(.FPOJ
M`@L!G@"?6D;=Z0RK#_;<3-SI`+QV`03J"@1&ZM=F&^L`"P.63.L!#!OK`PL`
MFT+J!`9,\0`,&^L&"TSQ``Q/ZHEQW`Y;`0*30>J8`0&;3^J(<-WI`F=$ZD,4
M3^J9`R9#W>D,11OK!@M/\``)3/$`#,WI$KS81D#J`0M!Z@,,1.H+`LWI#KR$
MJ]WI%JM/ZDD6W>D.O$;JV&8*Z@(*T^D``03J"P0&FU)&#_9`2]OI`*L#ED+J
M!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*32_$`"QKK!@K=Z0)G1.I)%$OQ``L`
M)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(W>D.14'JE@&P!T'J`PN&JU9&
MS>D`9T#J`0H!GM/I``%$Z@H"S>D&J]WI$KQV`0R;"^H""P"?6D;=Z0:K#_:P
M/-SI`+Q&ZM=F!.H*!`.6&^L`"T+J!`9,ZP$,&^L#"P";3/$`#!OK!@M/ZHEQ
M3/$`#$'JF`'<#EL!`I-/ZHAP`9O=Z0)G1.I#%$_JF0,F0]WI!D4;ZP8+3_``
M"4SQ``S-Z1*\V$9`Z@$+0>H##$3J"P+-Z0R\B*O=Z1:K3^I)%MWI#+Q&ZMAF
M"NH""M/I``$$Z@L$#IM21@_V&#O;Z0"K`Y9"Z@0&&NL`"D_JV&1+ZP$+&NL#
M"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+\0`+`"<F0S1&`9X:ZP0*`9Q+\0`+
MS>D6J[$'`)ZC"-WI#$5!ZI8!L`=!Z@,+5D9`Z@$*S>D`9\WI#JM$Z@H"W>D2
MO(JK`9X`GPOJ`@O3Z0`!6D9V`=WI#JM&ZM=F#_:$+-SI`+P#E@3J"@0&FQOK
M``M,ZP$,0NH$!AOK`PL`FTSQ``P;ZP8+3/$`#$_JB7'<#EL!`I-!ZI@!`9M/
MZHAPW>D"9T3J0Q1/ZID#)D/=Z0Y%&^L&"T_P``E,\0`,S>D2O-A&0.H!"T'J
M`PQ$Z@L"S>D&O(RKW>D6JT_J21;=Z0:\1NK89@KJ`@K3Z0`!!.H+!`R;4D8/
M]NP;V^D`JP.60NH$!AKK``I/ZMAD2^L!"QKK`PI/ZD@3`I-+\0`+&NL&"MWI
M`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<2_$`"\WI%JNQ!P">HPC=Z09%0>J6
M`;`'0>H#"U9&0.H!"LWI#*O=Z1*\1.H*`HZKS>D`9POJ`@L!GM/I``%:1MWI
M#*L/]F0<W.D`O'8!#IL$Z@H$&^L`"P"?3.L!#!OK`PL`FTSQ``Q&ZM=F`Y9"
MZ@0&3^J)<=P.6P$"DQOK!@L!FTSQ``S=Z0)G0>J8`4_JB'!/\``*1.I#%$_J
MF0,F0U=&&^L&"T#J`0I,\0`,S>D8O%Y&0>H#"U-&3_``"%Q&W>D,JT_P``G-
MZ0*)2NH#",WI#C1\`0.40D;=Z0Y%W>D6B9"I"NH$"<WI$F<(Z@((T>D``4Q&
M#_:P#-SI`+Q"1MWI$HD#GAOK``M,ZP$,!IM!1D;JV&9'1@.620$!G@*16$9"
MZ@0+_`[=Z0)XPAA$ZDD43/$``R=#$NL+`@&<3^J&<0">0_$``Q+K!PM/\``'
M0_$`#*,(0>J6`;`'7D;-Z0!GS>D6O``D0>H##``CS>D"-)*J`9M`Z@$+W>D.
M9]WI&(GA1M+I``%;`4;J"P(#DPCJ`@@&Z@L"`YY$1MA&#_8(#-SI`+PB0S=&
M`)X;ZP`+#)M,ZP$,1^K69P">6$;`&$SQ``&"&$_J1A,#EP*30?$``[M&%D8?
M1MWI`B-/\``,0NH+`A;K`@I'\0`+W>D29\WI&*O31LWI`KR]![0'1>J6!;D(
M1.H%"D7J`0L#FY2IW>D61<WI$HF(Z@H(`IJ$Z@@$S>D&JUL!T>D`O*!&#_*`
M<='I``%#ZM)C#IP;ZP`+'T9,ZP$,4P$;ZP0$`)Y,\0`%%.L("D/J!P@!FT7Q
M``NT!P&>&NL("D_J@W4`F]%&2_$`"[$(S>D6JT7JDP5*1D7J`0A$Z@4'EJE/
M\``*/49&1MWI!GA31LWI#%9O0-WI&$71Z0")?$`/\@AQT>D``<WI`",`)R9&
M$IP8ZP`(`)M)ZP$)&.L$!$GQ``7=Z0")V`X#FT_J1QM/ZD@:%.L&"$#J21!%
M\0`)G0<"FTKJ``88ZP8(1>J3!0*;1D9)\0`)S>D2B4OJUFN<!P.;1.H%"$_J
M1AJ9"$!&1>H!"9BK24;=Z0R)T^D`(XCJ``C-Z0X!1$8/\GQIV>D`B1CK`@A)
MZP,)W>D6(P:9`"-B0!CK`0`41DGQ``$0ZP0(2NH+!-WI`+Q!\0`)`"+-Z0(C
M3_``"ACK!`AA1E5&3^J!<0.1`YA91D_JD0)$1D#JFP$#D5E&3_```$_J@7$"
MD6%&0NJ,<D_JD0-/\``!S>D``4GQ``G=Z0(!S>D6B<%&&4,00VL!`9.+1MWI
M#A*:JX)&04#-Z0*KT^D`O(A&#_+84M+I`!(!FQOK`0L,F4SK`@Q#ZMEC&^L!
M``&3W>D2(TSQ``&["(+J"`*+1F$!`)&01N(.$.L(`-WI`(E"ZD422_$``4CJ
M`@A/\``)$.L("D_JAG!!\0`+N0=!ZI8!S>D2JT'J`PQ`Z@$+3^I)$P`F649B
M1MWI`KP`)\WI`&?01@&3B^H!"YRKS>D&$EY&#IG3Z0"K#_)`4]/I`",:ZP(*
M2^L#"P&;&NL!`$/JV&,!D]WI%B-+\0`!JPAR0(M&3^I($0"1%D9/ZMAB@!G=
MZ0!G0NI)$DOQ``$60P`G$.L&"D_JA'!!\0`+J0=!ZI0!5D;-Z0ZK`"1`Z@$*
M0>H#"P`E>P'-Z0!%448!D]WI!C3-Z0RK2T#>Z0"\#_*\0M+I`!(-]2!^'$8!
MFQOK`0L"F4SK`@Q#ZM9C&^L!``&3W>D2(TSQ``%/ZID#3_``#&)`BT9Q`0"1
M%$;R#@`9W>D`14+J1Q)+\0`!%$-E1A#K!`I/ZHAP0?$`"T_JB7%!ZI@!5$9`
MZ@$(0>H#"<WI$JMK`<)&#_)$0M+I`!++1LWI`JO>Z0"\0^K48]WI#(D-]21^
M&^L!"P:9`9-,ZP(,W>D.(QOK`0!,\0`!B.H*"(+J"`*["(M&80$`D9!&X@X0
MZP@`W>D`B4+J11)+\0`!3_``"4CJ`@@0ZP@*3^J&<$'Q``NY!T'JE@'-Z0ZK
M0>H##$#J`0M/ZDD3`"8`)\WI`&<!DZ*KT$991F)&W>D"J\WI!A+3Z0"\BNH!
M"NBCT^D`(PR95D8;ZP(+3.L##`&;&^L!`$/JV&,!D]WI$B-,\0`!JPAR0(M&
M3^I($0"1%D9/ZMAB@!G=Z0!G0NI)$DOQ``$60P`G$.L&"D_JA'!!\0`+J0=!
MZI0!`"5!Z@,,`"1[`<WI`$4!DU9&W>D&-,WI$JM`Z@$+@^H+`\WI#+S>Z0`2
M#?4F?@_R%#O;Z0"K'$8!FT_P``P1ZPH!0NL+`D/JUF.*1@*9`9.31AKK`0#=
MZ0XC2_$``4_JF0-B0(M&<0$`D11&\@X`&=WI`$5"ZD<22_$``65&%$,0ZP0*
M3^J(<$'Q``M/ZHEQ0>J8`51&S>D.JT#J`0E!Z@,*WND`$FL!#?4J?M-&RD;=
MZ0R)0^K48\WI`JN(Z@H(#_*$*]OI`*L!DQ'K"@%"ZPL"BD8&F9-&W>D2(QKK
M`0!/ZI<#2_$``8+J"`*+1F$!`)&01N(.$.L(`-WI`(E"ZDP22_$``4_P``E(
MZ@(($.L("D_JAG!!\0`+N0=!ZI8!`"<`)LWI`&=`Z@$&0>H#!]WI`A)/ZDD3
M`9.HJW%`T$;-Z09GS>D2JPY&#_+X&]OI`*O3Z0`2`9L1ZPH!0NL+`D/JV&.*
M1@R9DT8!D]WI#B,:ZP$`2_$``:L(<D"+1D_J2!$61@"1@!E/ZMABW>D`9T+J
M21)+\0`!`"<60Q#K!@I/ZH1P0?$`"ZD'0>J4`0`E0>H##``D>P'-Z0!%`9-6
M1MWI!C3-Z0ZK0.H!"X/J"P/-Z0R\WND`$D_P``P/\F@;V^D`JQQ&`9L-]2Q^
M$>L*`4+K"P)#ZM9CBD8"F0&3DT8:ZP$`W>D2(TOQ``%/ZID#8D"+1G$!`)$4
M1O(.`!G=Z0!%0NI'$DOQ``%E1A1#$.L$"D_JB'!!\0`+3^J)<4'JF`%41LWI
M$JM/\``(0>H#"D_P``G-Z0")0.H!"5)&:P%)1@&3S>D"$M[I`*L-]3!^-:/3
MZ0`CW>D,B1KK`@I+ZP,+B.H!"`&;!IE#ZM1C`9,:ZP$`W>D.(TOQ``&["(+J
M"`*+1F$!`)&01N(.$.L(`-WI`(E"ZDP22_$``4_P``E(Z@(($.L("D_JAG!!
M\0`+N0=!ZI8!T$;-Z0ZK0.H!"D'J`PL`)@`GS>D`9U9&7T;=Z0*K3^I)$P&3
MKJN*Z@8*$:+2Z0`2S>D&9U9&T^D`JP&;&NL!"D/JV&,!DPR92^L""]WI$B.K
M"!KK`0!+\0`!<D"+1D_J2!$)X*_S`(#<O!N/`````-;!8LH``````)$61D_J
MV&*`&=WI`&="ZDD22_$``0`G%D,0ZP8*3^J$<$'Q``NI!T'JE`$`)4'J`PP`
M)'L!S>D`10&35D;=Z08TS>D2JT#J`0N#Z@L#S>D,O-FBTND`$D_P``S>Z0"K
M'$8!FPWU,GX:ZP$*`IE+ZP(+0^K68QKK`0`!D]WI#B-+\0`!3^J9`V)`BT9Q
M`0"1%$;R#@`9W>D`14+J1Q)+\0`!%$-E1A#K!`I/ZHAP0?$`"T_JB7%!ZI@!
M5$9`Z@$)S>D.JT'J`PK>Z0`2:P$-]39^TT;*1MWI#(E#ZM1CS>D"JXCJ"@@/
M\M`KV^D`JP&3$>L*`4+K"P**1@:9DT;=Z1(C&NL!`$_JEP-+\0`!@NH(`HM&
M80$`D9!&X@X0ZP@`W>D`B4+J3!)+\0`!3_``"4CJ`@A/\``,$.L("D_JAG!!
M\0`+N0=!ZI8!`"<`)LWI`&=`Z@$&0>H#!]WI`A)/ZDD3`9.TJW%`T$;-Z09G
MS>D2JPY&#_)`*]OI`*O3Z0`2`9L1ZPH!0NL+`D/JV&.*1@&3#)F31MWI#B.K
M"!KK`0!+\0`!<D"+1D_J2!$`D19&3^K88H`9W>D`9T+J21)+\0`!`"<60Q#K
M!@I/ZH1P0?$`"ZD'0>J4`<WI%JM`Z@$$0>H#!4_J1QM61B%&W>D&-"I&S>D,
M$DM`;Z'1Z0`!2^K::\WX`+`<1M[I`"-/ZDH:#?4X?A(82T'-Z0XCW>D2(_L.
M`IEB0`&3%$8*1MWI#@&`&$'Q``$"&=WI`$5!\0`#3^J)<<WI`B-$Z@H$0>J8
M`=WI`JM/ZHAP3^J9`T#J`0A!Z@,)&NL$"D)&949+1MWI#(G-Z0XC5$;-Z0!%
MB.H""$VDU.D`-$OQ``O=Z19%3^J7"=[I`!*$Z@@$S>D2J\D83^J'>Z!&`)Q+
MZI8+NJ]+Z@D%`"/@#@:<K$8*&0&<$NL(`D#J1!``G$_J1!I`Z@H`3^J&>DKJ
M"P3=Z0Z:$AC7Z0!GHT:*Z@4*B>H+"<WI!KQ<`0`CR$;11@_RO`O;Z0"K1.K2
M;MWI$KS-^`S@&NL&"HSJ"0R+Z@@+S>D2O'!&#)Q/\``)W?CTPAKK!`94`0*4
M$IPV&=WI`D4$0R!&`)PV&-WI"`$`(8`93^J4"AJ>W>D`1<;I``%*ZH5ZW>D0
M5AN93^J$>*T82.H*""I&T?@`X-WI"E8&F6T8#IDN1MWI%$4`)608W>D$`0`A
M$.L(`+!&&I[T1<;I`B/&Z0:)QND(1<;I!`$#T0WU/WV]Z/"/_/<,[0"_K_,`
M@-;!8LH`````+>GX0Q]+>T0`*#G0'DJ;6-/X`)"Y\0`/,-`%>``M&+\]+12_
M`24`)171V?@`0'RQ!T:(1DY&*D8Y1B!&_/?R[1"Y8UT]*P_05O@$3P`L\M$@
M1KWH^(,%1A7X`3\`*QB_/2OYT2T:X.<!-:;K"08L1+80R/@`8"!&O>CX@TQ&
MY^<$1N7G\F0!`%`!``#PM8.P%4\%1A5+;$9_1/Y8,V@!DR%&*$;_]ZS_L+$1
M2P"8^U@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48H1O_WEO\`*.C1
M`9HS:)I"`=$#L/"]_/>0[&!D`0`8`0``4`$``"WI\$\,1M_X7)&%L%9+!D;Y
M1`IX6?@#4#TJ"+\!-"MH($8#D_SW\.P"J0=&,$;_]VW_@$8`*%/0_/?F[(="
M1ME*2P*:6?@#D$_J@@@P>``H&+\]*!2_`2``(`?0,$80^`$_`"L8OSTK^=&`
M&P(WV?@`H#A$_/>D[$KX"```*&O0V?@`('$<`I@S>%+X(``]*QB_`"L#<`G0
M0AP1^`$[$$8`*QB_/2L"^`$[]M$"1CTC`W`4^`$[`O@!/P`K^=$`(`.:*VB:
M0DK1!;"]Z/"/"/'_,!3X`3L`^`$_`"OYT>[G(DM9^`.0V?@`L-OX`#"#LUM&
M`.!01E/X!"\`\0$*`"KXT0,P@``:2GI$$VB+L0%&6$;\]Q3LR?@``.BQ3^J*
M"`-&"O$!`@`A0_@B$,WX"*",YP$C$V#\]T3L`9!@L4_JB@A91D)&_/>VZP&;
MR?@`,.?GFD8((-;G3_#_,+#G_/?:ZP"_]&,!`!@!``!0`0``E&0!`#1+-4I[
M1"WI\$.?L)Y8,V@=DQ"Q`W@'1C.Y'9HS:)I"5=$?L+WH\(/\]P3L!48`*//0
MW_BH@/A$*$;\]ZCL`"@[T,-\T_$N`P?1`WT`*_/0T_$N`Q2_6T)#?0`K[-``
M\1,$.$;\]Q;L@48@1OSW$NQ(1`(P_/?JZT-&3_#_,@$A`90`EX%&_/<D[$E&
M`JH#(/SWCNP!,$A&!=`&FP/T<$.S]8!/$-#\]XKK2$;\]T[K*$;\]VSL`"C#
MT2A&_/>6[#A&_/=6ZZCG__>:_^WG_/=HZP"_C&(!`!@!``!^$P``.+4%1A5+
M%DI[1)Q8(&C\]X3L*48`]:1R`R#\]W+L"+$`(#B](&C\]WCLT/A8,0/T<$.S
M]8!/"=`@:/SW;NS0^%@Q`_1P0[/U($_IT2A&`B'\]QKLL/J`\$`).+VH80$`
M(`$``"WI\$.M]8!=(4V#L"%+#?6`5GU$`:R`1A]([U@$-HE&0/;_<B%&>$0[
M:#-@_/<\ZP`H(=U&'J-=X[$&1C)&+R$@1OSWZNNXL11+ZU@8:/SW,NPS1B)&
M04;\]_SK#?6`4P0S&F@[:)I"$-$-]8!=`["]Z/"#`"[AT0A+ZU@8:/SW&NQ*
M1D%&_/<*Z^?G_/?FZCIA`0`8`0``4A(``"`!```0M0A,"$M\1.-8&&C\]P+L
M!DH'2P=)HEA[1'E$O>@00/SW>+NF8`$`(`$``!P!``"($0``SA$```U+#DI[
M1!"U@K"<6"!H_/?FZ__WV?\@:/SWX.L`(0A+`9$(2GM$"$EZ1`"3>43\]X+K
M`K`0O0"_<&`!`"`!``!\%```P0T``*`1```A2R)*>T3PM:WU`%V=6(>P#?4`
M4@.N%#(=3"MH?$038/SW^.H;2T'R`0(!(7M$C>@1`#!&_/<8ZP`H(=L-]8!7
M,$80-T_T@%(Y1OSWG.H$'A;;8!S\]\;J!D8HL3E&(D;\]TSJ`",S50WU`%,P
M1A0S&F@K:)I"!=$-]0!=![#PO0`F\>?\]UCJ)&`!`!@!``"($0``;!$``/_W
MLK\MZ?!/K?6!7=_X=(&#L%U+!$;X1`WU@5);2`0R6/@#,`WQ*`D-1GA$J?$(
M`063&V@38/_W+_TO(09&($;\][3JF+%22"%&>$3_]Y[]($8-]8%3!#,::`6;
M&VB:0D#PBH`-]8%=`["]Z/"/($;\]Y#J1TEY1()&*$;\]_KJ!T8`*-_01$O?
M^!"Q>T0&DT-+^T1[1`>3.W@`*TO0+K$Y1C!&_/>NZ0`H2M`X1OSW<NI"'KL8
MNEPO*@;1`"$9<`$X$_@!+2\J^=`*\0$#&$2P]8!?M]JI\00%,DH!(5M&>D0`
MEP&2*$9/](!2`I3\]W#J+4M8^`-P.&C\]_[J*48`]:1R`R#\]]3J2+DX:/SW
M].K0^%@Q`_1P0[/U`$\<T"))`"!Y1/SWINH'1@`OBM`[>``KL]%NL0:9,$;\
M]V+IX+D;20`@>43\]Y3J!T8`+^[1>.<'GP$@M^<!(2A&_/>$Z@`HW-$32"E&
M>$3_]P[]*$;\]SSJ;.?\]Y+I!I\!(*/G`+]Z7P$`&`$``.H0``#6$```NA``
M`(00``"B$```?!```%P0```@`0``#!```.H/``"V#P```W@[L4(<+RL(OQ!&
M$O@!.P`K^-%P1P"_.+6@LP5X!$:-L_SWW.D!."(8E$(,TB-<+RLQT5,>`N`1
M>"\I+-&<0AI&`_'_,_?1E$(:T`$Z`^`1>"\I!-$:1I1"`O'_,_?3$AN3'+/U
M@%\4V!5((48!,D_T@%-X1`0=($;\]S#I($8XO2\M%=$"(/SWA.D0L2XB`H`X
MO0`@.+U3'@+@$7@O*=30G$(:1@/Q_S/WTY1"S='GYP1(O>@X0'A$_/>YN0"_
M_%X!`,P.```MZ?!!C+!&3`*M1D]\1$9.##1_1-_X%($/S/A$OUD!K@_%#\S7
M^`#@#\4D:$!(S?@LX'A$+(#_]S7\/DAX1/_W,?P]2'A$__<M_#Q(>$3_]RG\
M.TAX1/_W)?PZ2'A$__<A_#E(>$3_]QW\.$AX1/_W&?Q`1O_W%OPU2'A$__<2
M_#1(>$3_]P[\,T@Q1GA$__?#^QBQ`49`1O_W./PO2#%&>$3_][G[(+$!1BU(
M>$3_]RW\+$@Q1GA$__>N^XBQ`48I2'A$__<B_"A)*4AY1'A$__<<_`N:.VB:
M0A[1#+"]Z/"!)$@Q1GA$__>6^RBQ`48A2'A$__<*_.;G($D*(@WQ&0!Y1/SW
MFND`*-W1'$@-\2,!>$3_]_K[UN?\]X+H`+_X#0``_EP!`!@!``#V#@``C@X`
M`)`.``"0#@``E`X``)0.``"<#@``,`X``)@.``"B#@``'@X``)P.``"<#@``
MI`X``*8.``#2#0``P`X``!H.``"&#@``$@X``'X.``#R#0``$DD32GE$$TL0
MM7M$C%B"L!AH(V@!DT,<!=`!FB-HFD(2T0*P$+T,2&E&>$3_]S+[,+$`>#`H
M&+\`*!2_`2``(`9+>T088.CG_/<HZ(A;`0`8`0``WEP!`%8-``"F7`$`"+7[
M]^;O^_?8[P"Q`&@(O2%+(DI[1"WI\$&&L)Q8!48?3P2I(VA_1#A&!9/_]P+[
M*49@L0-X!D9+L?OWK.]8L06:(VB:0B31!K"]Z/"!%4AX1/_W:?OSYRA&_/=J
MZ(!&,$;\]V;H0$0",/SW/N@.2T_P_S("EGM$`9,,2P$A`)5[1(!&_/=RZ$%&
M.$;_]TS[UN?[]]3O`+\86P$`&`$``(8-``!<#0``5@P``%`,```MZ?!/K?4!
M3=_X:$>3L%*KW_ADAWQ$"Y,B'1Y&W_A<-_A$#)"F\?@'!\H$\1`.6/@#,*;Q
MX`LH-*;Q[`G:1OP^'48-DX?H!P"^Z`\`U?@`P*KH#P`-]0%#GN@#`$0SP_@`
MP(KH`P"4Z`<`B>@'`#%&W_@,!WA$__>%^B"Q`W@$1@`K0/"+@?_W8_\%1@`H
M7-`H1OOW]N]```$P^_?.[RMX@4:#L=_XW*9,1OI$`),@1E-&3_#_,@$A`C3\
M]P#H%?@!/P`K\M$+FU/XX`P8N17@6_@$#Y"Q,4;_]U3Z!$8`*/;0`W@`*_/0
M__?P^P`H[]`@1OOW\N\%1@`H-=$`)%?X)%"%LRMX<[,H1@3Q`0H'ZX0$__?;
M^UBY5/@$7QVS*W@+LRA&"O$!"O_WT/L`*//0*$941OOWT.\`*.#0!483X/OW
MRN\`*$#P.8%9^`0+`"@`\"N!,4;_]Q7Z`"CUT`-X`"ORT.SG`"4H1M_X'';[
M]XCO?T0$1DA&^_>"[P1$!/($1"!&^_=8[]_X`#9/\/\R`2%[1`&3W_CX-<WX
M#)![1`"5`I>#1OOWBN]81D_TX''[]Z#O`3`NT-_XV#58^`-P.&C\]Q#H648`
M]:1R`R#[]_[O!48`*#70W_B\!0$A#)L`)-_XN"58^```&VAZ1,WX`+``:/OW
MG.\-]0%#($9$,QIH#9L;:)I"0/"<@@WU`4T3L+WH\(_[]TSO`F@1*LO0W_AT
M!0$A#)L`)%CX```;:`&2W_AL)<WX`+!Z1`!H^_=X[]GG.&C[]\[OT/A8,0/T
M<$.S]8!/O]$X:/OWQ._0^&"1^_=>[H%%MM$X:/OWNN_0^%@QP_,(`[/UX'^L
MT2!&^_?:[C%&!$;?^!@%>$3_]WGY`"@`\)2`#)L>:/OW'.\!1C!&__<D_`9&
M`"@`\(B`,$;[]^;N`R@'1A#=W_CH%`0X,$1Y1/OW%.Y`N00O`/#@@3=$%_@%
M/"\K`/#:@?_W!_XPN0%&,$;[]Z#N#I``*&G1W_BX%-_XN`1Y1-_XM'1X1-_X
MM)3_][?Y?T3[]ZSNW_BH--_XJ!1/\/\R>T0!D]_XH#1Y1-_XH(2Z1@.1>T3-
M^`"P`2'Y1/A$7T8"D"!&^_>\[A3@^_>T[@-H$2L7T?OWBNX!-<WX$(`R1@.5
M2T;-^`2@`2$`EP*0($;[]Z;N3_3@<2!&^_>^[D,<!D;BT+M&6$;[]]CMW_A`
M!"%&>$3_]W+Y($;_]^/]+>?_]^#]($;[]YKN!$8FYPT@W_@@5/OW0NY3(WU$
M@49SY@5&9^8,FQYH=.<+GV_P$0(")0"5.Q\,DQY&3_#_,_OW%NXQ1@8B#IC[
M]Y;M%_@$/!NY<WA#*P#P<H$`)0`B`",`E0Z8^_<"[@N>T:'1Z0`!IO'("M"C
MT^D`(\KX>%#*Z0(!IO&0`0^1S:'1Z0`!RND$(\VCT^D`(\KI!@',H='I``'*
MZ0@C`"(`(Q"4RND*(\KI#"-&Z3(!S?A$L$_T`$(,F0Z8^_=8[00>>MWG%]KI
M"B,F1OD`0>I4<0>1X0`&D=WI!HE/\``)&.L"")E%"+^01=KI#","T@$R0_$`
M`W$/VOAX`$'JQP$(D7D/"9'=Z0A6RND*B:T87D$J1C-&RND,(P`H2M#`\4`(
M#YN@10R9&$2HOZ!&0D;[]SSMVOAX,$-$ROAX,$`KN-$,FU!&I.L(!)A$_/<$
M^#\L)MU`/`N=)/`_"PCQ0`P+\8`)P42L\4`&I?&0#C!H$#96^`P<=T96^`@L
M#O$0#E;X!#QF10_'\=%01OOWY/\&\4`,S$7FT0OQ0`L$\#\$V$1!1D@C(D8/
MF/OW2NW*^'A`?^?=^#"`RN<+FPZ8H_&0!Q"<W?A$L/OW*.[:^"A0@"':^#!@
MQ?/%`E,<."NY5`#SFH#X&,/Q.`(`(?OWMNU01BH.,PZ*^'0@BOAS8(KX=U"*
M^'`P,PPV"HKX<3"*^')@*PPM"HKX=3"*^'90^_>;_PN8VO@(8*#Q1`+:^!!0
M4/C([*#Q,`>@\0@(W_CPD=5R3^H>04_J'F-1</E$VO@@$`#X1#S:^!@`@O@#
MX$_J'B[1=(+X`N!/ZA9NT'."^`3@3^H63H+X!>#6<38*EG$N#A9R+@PM"E9R
ME7(61@4.%7,%#``*57,]1I!S"`X0=`@,"0I0=)%T`>`6^`$_`),H1DM&3_#_
M,@$A`C7[]RSMJ$7RT5M(3_#_,EM+`2%X1`*7`Y![1,WX`+`@1@&3`".'^"@P
M54M[1/OW%NUWY@R;7V@`+S_T(:XX1OOW\.P#*'_V&ZY.200X.$1Y1/OW'NP`
M*`B_/D80YL/Q0`+X&``A^_<<[5!&^_<7_SA&."(`(?OW%.U<YPR;FWA!*W_T
MB:X,F]MX0RM_](2N#)L;>4@K?_1_K@R;6WE%*W_T>JX`E4_P_S,.G6_P.0(H
M1OOW>NP,GBA&*2(S33%&^_?ZZS)+?41/\/\R>T0!DS!+`2$"EB!&S?@`L'M$
M`Y7[][[L'N;[]R+LK_,`@(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`
M`````2-%9P````#$6P$`7%H!`!@!``","P``:@P``+8+``"6"@``?@L``"`!
M```H`0``S`L``/8*```D"P``J`H``/X)``!P"0``'@D``&8*```,"0``A`L`
M`%X*``!P"P``<@@``%8)```D!P``-@@``+`%``#R!@``Q@8``(0'``#^!```
M0@8``)E*FDDMZ?!/>D2'L)A+!*T"E5!8`6@#D`61UE@P:/OWZ.P$1C!H^_?D
M["E&D/AH,)!(A/AI,'A$_O>J_ABQ`W@Q*P#PWH#_]Y?Z,&C[]]#LB4D+(P$B
M>43[]P#L`"A+T(9+`FE[1%/X]#S2^!B``2M"W=_X#*)/](!IW_@(LL#R(`GZ
M1``E^T0!)"/@`6A:^/`,BVA0^"1P">H#`[/U@&\(OPEI"M`P:`&2^_>B[`&:
M`B,1:``B^_>BZP%&.$;[]Q[K`"A`\)2`6_CT/`$T`36C0@[=,&C[]XSL*D8`
M(T%&^_=*[`)&`"C0T6=+>T13^/0\6AZJ0FK0,&C[]WKL8TD#(P$B>43[]ZKK
M!$9PL3!H^_=N["-I7DH9:'I$^_=<ZR-I&VB;:%L"`/&)@#!H^_=@[%A)`R,!
M(GE$^_>0ZP1&>+%52`*9>$3^]R+^!48P:``M:-#[]TSL(VDJ1AEH^_<\ZS!H
M^_=$[$Q-?40$1C!H^_<^[$I)`2)Y1/OWFNM)2GI$`48@1OOW*.LP:/OW,.P`
M(@*9`T9$2(/X:2!X1/[W]_T$1D7X[`R`LT_TX'$@1OOWINM#'!$H&+\!*TG8
M`YL%FAMHFD)"T0>PO>CPCP$KDMTV30$D?40P:`$T^_<([$%&^_>VZE7X]#RC
M0O3<@^<O2WM$4_CT/%H>JD)_]'ROY>=#>``K/_0@KQSG5?CP#/_W_/H$1D7X
M[`P`*,71)4AX1/OW6.O[]^3K(TLB:7M$4_CP/!!H&6C^]X#_D><P:/OWUNLC
M:1EH^_=LZV[G^_>DZAI)`T8:2")&>41X1%'X\!P):/OW-NN`4@$`&`$``"`!
M```J!```P@4``+1D`0"69`$`DF0!`"QD`0`<!0``"@4``/0$``#2`@``KF,!
M`+@$``#(!```<`(``$)C`0`F8P$`,`0``.IB`0"^8@$`&`0``#BU!4;_]_[X
M`WC#L4(<!$8O*PB_%$82^`$[`"OXT?_W"_H`+1B_`"@(T"MX,[$'22!&>43[
M]_KIA$("T#B]!$;MYRA&O>@X0/[W=+X^`@``!4L0M'M$!4P;60.Q&VA=^`1+
M^_<]N@"_<$\!`#`!```MZ?A#!T8+3HA&"TV11GY$^_?$Z7U$=ANV$`G0`"0!
M-%7X!#M*1D%&.$:81Z9"]M&]Z/B#%DX!``Q.`0!P1P"_"$`MZ0B`O>@!``(`
M<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``
M````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$
M>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S
M`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%`````#H````E<R5S
M)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)
M3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!
M4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%2
M7T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````3$1?3$E"4D%2
M65]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````4$%42``````E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!!4D=6````
M`!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`S
M-P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%````
M`%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H
M*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D[
M"G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!
M5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P*
M*3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT
M(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K
M(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D
M(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M
M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH
M)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@
M<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"
M14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A
M=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7
M:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S
M971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L
M("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY
M("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D
M:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F
M<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;
M<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@
M<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O
M;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*
M)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I
M9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@
M*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P
M.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#([
M"G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A
M8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U
M9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM
M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@
M/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^
M(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D
M*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U
M-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE
M;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U
M;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A
M;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H
M(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T
M>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#
M(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O
M<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D
M;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS
M965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE
M;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@
M9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D[
M"G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL
M96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE
M(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@
M;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R
M."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO
M="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2([
M"GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II
M<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z
M)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P
M87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL
M92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I
M;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H
M*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N
M9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(
M/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L
M("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@
M+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*
M?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X[
M"F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL
M92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]
M"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE
M+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E
M<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(
M96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]
M*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@
M)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY
M("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I
M92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N
M=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M
M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E
M,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I
M+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z
M.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T
M.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U
M+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I
M;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H
M95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O
M:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN
M97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]
M+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD
M"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&
M:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N
M86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E
M<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M
M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA
M;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V
M97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[
M"FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E
M<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`*QX
M_W\!````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````#]&```O1@`
M```````!`````0````$```#?`0```0```.H!```!````]`$```$```!#`@``
M`0```)X#```!````Q`,```P```#P$@``#0```)1?```9````>*T!`!L````$
M````&@```'RM`0`<````!````/7^_V^T`0``!0```)`)```&````H`(```H`
M```H!0``"P```!`````5``````````,```"LK@$``@`````"```4````$0``
M`!<```#P$```$0```/@/```2````^````!,````(````'@````@```#[__]O
M`0``"/[__V^8#P``____;P,```#P__]ON`X``/K__V\1````````````````
M`````````````````````````````````````````(2M`0```````````/P2
M``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(`
M`/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``
M_!(``/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``#\
M$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(``/P2
M``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``#\$@``_!(`
M`/P2``#\$@``_!(``/P2``#\$@``_!(``/P2``"17P``````````````````
M```````````````````````````$L`$``````%5?````````(18`````````
M````````````````````!+`!`/____\$8P``+&````````#L8```\&```/AB
M```T8````&,```````#D8@``[&(````````,8P``1T-#.B`H1&5B:6%N(#8N
M-"XP+3(I(#8N-"XP(#(P,3<P-S(T`$$R````865A8FD``2@````%-RU!``8*
M!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R
M<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N
M<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!
M4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ
M8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M```````+`````0````(```!4`0``5`$``!D```````````````$`````````
M$P````<````"````<`$``'`!```@```````````````$`````````"$````'
M`````@```)`!``"0`0``)```````````````!``````````T````]O__;P(`
M``"T`0``M`$``.P````%``````````0````$````/@````L````"````H`(`
M`*`"``#P!@``!@````,````$````$````$8````#`````@```)`)``"0"0``
M*`4``````````````0````````!.````____;P(```"X#@``N`X``-X````%
M``````````(````"````6P```/[__V\"````F`\``)@/``!@````!@````,`
M```$`````````&H````)`````@```/@/``#X#P``^`````4`````````!```
M``@```!S````"0```$(```#P$```\!`````"```%````%@````0````(````
M?`````$````&````\!(``/`2```,```````````````$`````````'<````!
M````!@```/P2``#\$@``(`,`````````````!`````0```""`````0````8`
M```@%@``(!8``'1)``````````````@`````````B`````$````&````E%\`
M`)1?```(```````````````$`````````(X````!`````@```)Q?``"<7P``
MI#\`````````````!`````````"6`````0``<((```!`GP``0)\```@````-
M``````````0`````````H0````$````"````2)\``$B?```$````````````
M```$`````````*L````.`````P```'BM`0!XK0``!```````````````!```
M``0```"W````#P````,```!\K0$`?*T```0```````````````0````$````
MPP````$````#````@*T!`("M```$```````````````$`````````,@````&
M`````P```(2M`0"$K0``*`$```8`````````!`````@```#1`````0````,`
M``"LK@$`K*X``%0!``````````````0````$````U@````$````#`````+`!
M``"P``!````````````````$`````````-P````(`````P```$"P`0!`L```
M&!``````````````!`````````#A`````0```#``````````0+```"4`````
M``````````$````!````Z@````,``'```````````&6P```S````````````
M```!``````````$````#``````````````"8L```^@```````````````0``
%````````
